==> v3.9.tar.gz: privacyguides.org/docs/financial-services.md <==
---
title: Financial Services
icon: material/bank
---

Making payments online is one of the biggest challenges to privacy. These services can assist you in protecting your privacy from merchants and other trackers, provided you have a strong understanding of how to make private payments effectively. We strongly encourage you first read our payments overview article before making any purchases:

[Making Private Payments :material-arrow-right-drop-circle:](advanced/payments.md){ .md-button }

## Payment Masking Services

There are a number of services which provide "virtual debit cards" which you can use with online merchants without revealing your actual banking or billing information in most cases. It's important to note that these financial services are **not** anonymous and are subject to "Know Your Customer" (KYC) laws and may require your ID or other identifying information. These services are primarily useful for protecting you from merchant data breaches, less sophisticated tracking or purchase correlation by marketing agencies, and online data theft; and **not** for making a purchase completely anonymously.

!!! tip "Check your current bank"

    Many banks and credit card providers offer native virtual card functionality. If you use one which provides this option already, you should use it over the following recommendations in most cases. That way you are not trusting multiple parties with your personal information.

### Privacy.com (US)

!!! recommendation

    ![Privacy.com logo](assets/img/financial-services/privacy_com.svg#only-light){ align=right }
    ![Privacy.com logo](assets/img/financial-services/privacy_com-dark.svg#only-dark){ align=right }

    **Privacy.com**'s free plan allows you to create up to 12 virtual cards per month, set spend limits on those cards, and shut off cards instantly. Their paid plan allows you to create up to 36 cards per month, get 1% cash back on purchases, and hide transaction information from your bank.

    [:octicons-home-16: Homepage](https://privacy.com){ .md-button .md-button--primary }
    [:octicons-eye-16:](https://privacy.com/privacy-policy){ .card-link title="Privacy Policy" }
    [:octicons-info-16:](https://support.privacy.com/hc/en-us){ .card-link title=Documentation}

Privacy.com gives information about the merchants you purchase from to your bank by default. Their paid "discreet merchants" feature hides merchant information from your bank, so your bank only sees that a purchase was made with Privacy.com but not where that money was spent, however that is not foolproof, and of course Privacy.com still has knowledge about the merchants you are spending money with.

### MySudo (US, Paid)

!!! recommendation

    ![MySudo logo](assets/img/financial-services/mysudo.svg#only-light){ align=right }
    ![MySudo logo](assets/img/financial-services/mysudo-dark.svg#only-dark){ align=right }

    **MySudo** provides up to 9 virtual cards depending on the plan you purchase. Their paid plans additionally include functionality which may be useful for making purchases privately, such as virtual phone numbers and email addresses, although we typically recommend other [email aliasing providers](email.md) for extensive email aliasing use.

    [:octicons-home-16: Homepage](https://mysudo.com/){ .md-button .md-button--primary }
    [:octicons-eye-16:](https://anonyome.com/privacy-policy/){ .card-link title="Privacy Policy" }
    [:octicons-info-16:](https://support.mysudo.com/hc/en-us){ .card-link title=Documentation}

### Criteria

**Please note we are not affiliated with any of the projects we recommend.** In addition to [our standard criteria](about/criteria.md), we have developed a clear set of requirements to allow us to provide objective recommendations. We suggest you familiarize yourself with this list before choosing to use a project, and conduct your own research to ensure it's the right choice for you.

!!! example "This section is new"

    We are working on establishing defined criteria for every section of our site, and this may be subject to change. If you have any questions about our criteria, please [ask on our forum](https://discuss.privacyguides.net/latest) and don't assume we didn't consider something when making our recommendations if it is not listed here. There are many factors considered and discussed when we recommend a project, and documenting every single one is a work-in-progress.

- Allows the creation of multiple cards which function as a shield between the merchant and your personal finances.
- Cards must not require you to provide accurate billing address information to the merchant.

## Gift Card Marketplaces

These services allow you to purchase gift cards for a variety of merchants online with [cryptocurrency](cryptocurrency.md). Some of these services offer ID verification options for higher limits, but they also allow accounts with just an email address. Basic limits typically start at $5,000-10,000 a day for basic accounts, and significantly higher limits for ID verified accounts (if offered).

### Cake Pay

!!! recommendation

    ![CakePay logo](assets/img/financial-services/cakepay.svg){ align=right }

    **Cake Pay** allows you to purchase gift cards and related products with Monero. Purchases for USA merchants are available in the Cake Wallet mobile app, while the Cake Pay web app includes a broad selection of global merchants.

    [:octicons-home-16: Homepage](https://cakepay.com/){ .md-button .md-button--primary }
    [:octicons-eye-16:](https://ionia.docsend.com/view/jhjvdn7qq7k3ukwt){ .card-link title="Privacy Policy" }
    [:octicons-info-16:](https://guides.cakewallet.com/){ .card-link title=Documentation}

### CoinCards

!!! recommendation

    ![CakePay logo](assets/img/financial-services/coincards.svg){ align=right }

    **CoinCards** (available in the US, Canada, and UK) allows you to purchase gift cards for a large variety of merchants.

    [:octicons-home-16: Homepage](https://coincards.com/){ .md-button .md-button--primary }
    [:octicons-eye-16:](https://coincards.com/privacy-policy/){ .card-link title="Privacy Policy" }
    [:octicons-info-16:](https://coincards.com/frequently-asked-questions/){ .card-link title=Documentation}

### Criteria

**Please note we are not affiliated with any of the projects we recommend.** In addition to [our standard criteria](about/criteria.md), we have developed a clear set of requirements to allow us to provide objective recommendations. We suggest you familiarize yourself with this list before choosing to use a project, and conduct your own research to ensure it's the right choice for you.

!!! example "This section is new"

    We are working on establishing defined criteria for every section of our site, and this may be subject to change. If you have any questions about our criteria, please [ask on our forum](https://discuss.privacyguides.net/latest) and don't assume we didn't consider something when making our recommendations if it is not listed here. There are many factors considered and discussed when we recommend a project, and documenting every single one is a work-in-progress.

- Accepts payment in [a recommended cryptocurrency](cryptocurrency.md).
- No ID requirement.

==> v3.12.1.tar.gz: privacyguides.org/docs/financial-services.md <==
---
title: Financial Services
icon: material/bank
cover: financial-services.png
---

Making payments online is one of the biggest challenges to privacy. These services can assist you in protecting your privacy from merchants and other trackers, provided you have a strong understanding of how to make private payments effectively. We strongly encourage you first read our payments overview article before making any purchases:

[Making Private Payments :material-arrow-right-drop-circle:](advanced/payments.md){ .md-button }

## Payment Masking Services

There are a number of services which provide "virtual debit cards" which you can use with online merchants without revealing your actual banking or billing information in most cases. It's important to note that these financial services are **not** anonymous and are subject to "Know Your Customer" (KYC) laws and may require your ID or other identifying information. These services are primarily useful for protecting you from merchant data breaches, less sophisticated tracking or purchase correlation by marketing agencies, and online data theft; and **not** for making a purchase completely anonymously.

!!! tip "Check your current bank"

    Many banks and credit card providers offer native virtual card functionality. If you use one which provides this option already, you should use it over the following recommendations in most cases. That way you are not trusting multiple parties with your personal information.

### Privacy.com (US)

!!! recommendation

    ![Privacy.com logo](assets/img/financial-services/privacy_com.svg#only-light){ align=right }
    ![Privacy.com logo](assets/img/financial-services/privacy_com-dark.svg#only-dark){ align=right }

    **Privacy.com**'s free plan allows you to create up to 12 virtual cards per month, set spend limits on those cards, and shut off cards instantly. Their paid plan allows you to create up to 36 cards per month, get 1% cash back on purchases, and hide transaction information from your bank.

    [:octicons-home-16: Homepage](https://privacy.com){ .md-button .md-button--primary }
    [:octicons-eye-16:](https://privacy.com/privacy-policy){ .card-link title="Privacy Policy" }
    [:octicons-info-16:](https://support.privacy.com/hc/en-us){ .card-link title=Documentation}

Privacy.com gives information about the merchants you purchase from to your bank by default. Their paid "discreet merchants" feature hides merchant information from your bank, so your bank only sees that a purchase was made with Privacy.com but not where that money was spent, however that is not foolproof, and of course Privacy.com still has knowledge about the merchants you are spending money with.

### MySudo (US, Paid)

!!! recommendation

    ![MySudo logo](assets/img/financial-services/mysudo.svg#only-light){ align=right }
    ![MySudo logo](assets/img/financial-services/mysudo-dark.svg#only-dark){ align=right }

    **MySudo** provides up to 9 virtual cards depending on the plan you purchase. Their paid plans additionally include functionality which may be useful for making purchases privately, such as virtual phone numbers and email addresses, although we typically recommend other [email aliasing providers](email.md) for extensive email aliasing use.

    [:octicons-home-16: Homepage](https://mysudo.com/){ .md-button .md-button--primary }
    [:octicons-eye-16:](https://anonyome.com/privacy-policy/){ .card-link title="Privacy Policy" }
    [:octicons-info-16:](https://support.mysudo.com/hc/en-us){ .card-link title=Documentation}

### Criteria

**Please note we are not affiliated with any of the projects we recommend.** In addition to [our standard criteria](about/criteria.md), we have developed a clear set of requirements to allow us to provide objective recommendations. We suggest you familiarize yourself with this list before choosing to use a project, and conduct your own research to ensure it's the right choice for you.

!!! example "This section is new"

    We are working on establishing defined criteria for every section of our site, and this may be subject to change. If you have any questions about our criteria, please [ask on our forum](https://discuss.privacyguides.net/latest) and don't assume we didn't consider something when making our recommendations if it is not listed here. There are many factors considered and discussed when we recommend a project, and documenting every single one is a work-in-progress.

- Allows the creation of multiple cards which function as a shield between the merchant and your personal finances.
- Cards must not require you to provide accurate billing address information to the merchant.

## Gift Card Marketplaces

These services allow you to purchase gift cards for a variety of merchants online with [cryptocurrency](cryptocurrency.md). Some of these services offer ID verification options for higher limits, but they also allow accounts with just an email address. Basic limits typically start at $5,000-10,000 a day for basic accounts, and significantly higher limits for ID verified accounts (if offered).

### Cake Pay

!!! recommendation

    ![CakePay logo](assets/img/financial-services/cakepay.svg){ align=right }

    **Cake Pay** allows you to purchase gift cards and related products with Monero. Purchases for USA merchants are available in the Cake Wallet mobile app, while the Cake Pay web app includes a broad selection of global merchants.

    [:octicons-home-16: Homepage](https://cakepay.com/){ .md-button .md-button--primary }
    [:octicons-eye-16:](https://ionia.docsend.com/view/jhjvdn7qq7k3ukwt){ .card-link title="Privacy Policy" }
    [:octicons-info-16:](https://guides.cakewallet.com/){ .card-link title=Documentation}

### CoinCards

!!! recommendation

    ![CoinCards logo](assets/img/financial-services/coincards.svg){ align=right }

    **CoinCards** (available in the US and Canada) allows you to purchase gift cards for a large variety of merchants.

    [:octicons-home-16: Homepage](https://coincards.com/){ .md-button .md-button--primary }
    [:octicons-eye-16:](https://coincards.com/privacy-policy/){ .card-link title="Privacy Policy" }
    [:octicons-info-16:](https://coincards.com/frequently-asked-questions/){ .card-link title=Documentation}

### Criteria

**Please note we are not affiliated with any of the projects we recommend.** In addition to [our standard criteria](about/criteria.md), we have developed a clear set of requirements to allow us to provide objective recommendations. We suggest you familiarize yourself with this list before choosing to use a project, and conduct your own research to ensure it's the right choice for you.

!!! example "This section is new"

    We are working on establishing defined criteria for every section of our site, and this may be subject to change. If you have any questions about our criteria, please [ask on our forum](https://discuss.privacyguides.net/latest) and don't assume we didn't consider something when making our recommendations if it is not listed here. There are many factors considered and discussed when we recommend a project, and documenting every single one is a work-in-progress.

- Accepts payment in [a recommended cryptocurrency](cryptocurrency.md).
- No ID requirement.
